@@ -211,6 +211,7 @@ const FILENAME_ICONS: Map<&'static str, char> = phf_map! {
     ".editorconfig"       => '\u{e652}',            // 
     ".emacs"              => Icons::EMACS,          // 
     ".envrc"              => '\u{f462}',            // 
+    ".eslintignore"       => Icons::ESLINT,         // 
     ".eslintrc.cjs"       => Icons::ESLINT,         // 
     ".eslintrc.js"        => Icons::ESLINT,         // 
     ".eslintrc.json"      => Icons::ESLINT,         // 
@@ -242,6 +243,7 @@ const FILENAME_ICONS: Map<&'static str, char> = phf_map! {
     ".npmignore"          => Icons::NPM,            // 
     ".npmrc"              => Icons::NPM,            // 
     ".pre-commit-config.yaml" => '\u{f06e2}',       // 󰛢
+    ".prettierignore"     => '\u{e6b4}',            // 
     ".prettierrc"         => '\u{e6b4}',            // 
     ".parentlock"         => Icons::LOCK,           // 
     ".profile"            => Icons::SHELL,          // 󱆃
@@ -271,8 +273,8 @@ const FILENAME_ICONS: Map<&'static str, char> = phf_map! {
     "AUTHORS"             => '\u{edca}',            // 
     "AUTHORS.txt"         => '\u{edca}',            // 
     "bashrc"              => Icons::SHELL,          // 󱆃
-    "brewfile"            => '\u{f1116}',           // 󱄖
-    "brewfile.lock.json"  => '\u{f1116}',           // 󱄖
+    "Brewfile"            => '\u{f1116}',           // 󱄖
+    "Brewfile.lock.json"  => '\u{f1116}',           // 󱄖
     "bspwmrc"             => '\u{f355}',            // 
     "build.gradle.kts"    => Icons::GRADLE,         // 
     "build.zig.zon"       => '\u{e6a9}',            // 
@@ -309,6 +311,7 @@ const FILENAME_ICONS: Map<&'static str, char> = phf_map! {
     "COMMIT_EDITMSG"      => Icons::GIT,            // 
     "environment"         => Icons::CONFIG,         // 
     "favicon.ico"         => '\u{e623}',            // 
+    "flake.lock"          => '\u{f313}',            // 
     "fonts.conf"          => Icons::FONT,           // 
     "fp-info-cache"       => Icons::KICAD,          // 
     "fp-lib-table"        => Icons::KICAD,          // 
@@ -380,6 +383,7 @@ const FILENAME_ICONS: Map<&'static str, char> = phf_map! {
     "Makefile.in"         => Icons::MAKE,           // 
     "MANIFEST"            => Icons::LANG_PYTHON,    // 
     "MANIFEST.in"         => Icons::LANG_PYTHON,    // 
+    "mix.lock"            => Icons::LANG_ELIXIR,    // 
     "mpv.conf"            => '\u{f36e}',            // 
     "npm-shrinkwrap.json" => Icons::NPM,            // 
     "npmrc"               => Icons::NPM,            // 
@@ -403,6 +407,7 @@ const FILENAME_ICONS: Map<&'static str, char> = phf_map! {
     "README"              => Icons::README,         // 󰂺
     "README.md"           => Icons::README,         // 󰂺
     "release.toml"        => Icons::LANG_RUST,      // 
+    "renovate.json"       => '\u{f027c}',           // 󰉼
     "requirements.txt"    => Icons::LANG_PYTHON,    // 
     "robots.txt"          => '\u{f06a9}',           // 󰚩
     "rubydoc"             => Icons::LANG_RUBYRAILS, // 
@@ -559,6 +564,8 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "dylib"          => Icons::OS_APPLE,         // 
     "ebook"          => Icons::BOOK,             // 
     "ebuild"         => '\u{f30d}',              // 
+    "editorconfig"   => '\u{e652}',              // 
+    "eex"            => Icons::LANG_ELIXIR,      // 
     "ejs"            => '\u{e618}',              // 
     "el"             => Icons::EMACS,            // 
     "elc"            => Icons::EMACS,            // 
@@ -655,6 +662,7 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "hex"            => '\u{f12a7}',             // 󱊧
     "hh"             => Icons::LANG_CPP,         // 
     "hpp"            => Icons::LANG_CPP,         // 
+    "hrl"            => '\u{e7b1}',              // 
     "hs"             => Icons::LANG_HASKELL,     // 
     "htm"            => Icons::HTML5,            // 
     "html"           => Icons::HTML5,            // 
@@ -727,6 +735,7 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "lbr"            => Icons::LIBRARY,          // 
     "lck"            => Icons::LOCK,             // 
     "ldb"            => Icons::DATABASE,         // 
+    "leex"           => Icons::LANG_ELIXIR,      // 
     "less"           => '\u{e758}',              // 
     "lff"            => Icons::FONT,             // 
     "lhs"            => Icons::LANG_HASKELL,     // 
@@ -790,6 +799,7 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "ninja"          => '\u{f0774}',             // 󰝴
     "nix"            => '\u{f313}',              // 
     "node"           => Icons::NODEJS,           // 
+    "norg"           => '\u{e847}',              // 
     "nsp"            => '\u{F07E1}',             // 󰟡
     "nu"             => Icons::SHELL_CMD,        // 
     "o"              => Icons::BINARY,           // 
@@ -845,6 +855,7 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "prql"           => Icons::DATABASE,         // 
     "ps"             => Icons::VECTOR,           // 󰕙
     "ps1"            => Icons::POWERSHELL,       // 
+    "psb"            => '\u{e7b8}',              // 
     "psd"            => '\u{e7b8}',              // 
     "psd1"           => Icons::POWERSHELL,       // 
     "psf"            => Icons::FONT,             // 
